/*
** Module   : SaxEntity
** Abstract : SAX attributes, reader, writer common interface.
**
** Copyright (c) 2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ---------------------------------Description----------------------------------
** 001 EVL 20130208 Created initial version.
*/

package com.goldencode.p2j.xml;

import com.goldencode.p2j.util.*;

/**
 * Interface decribing the common features for SAX Reader, SAX Writer and SAX Attributes Progress
 * support objects.
 */
public interface SaxEntity
extends XCommon
{
   // Attributes
   // Methods
   /**
    * Adding the single attribute to the start tag in the XML document if applied for SAX writer
    * object. For SAX attributes object inserts attribute and its name into SAX attributes object.
    * 
    * @param    attributeName
    *           The attribute name to insert.
    * @param    attributeValue
    *           The attribute value to insert.
    * @param    namespaceUri
    *           The URI of the attribute to insert or '?' for unknown value.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   public logical insertAttribute(Text attributeName, Text attributeValue,
                                  Text namespaceUri);

   /**
    * Adding the single attribute to the start tag in the XML document if applied for SAX writer
    * object. For SAX attributes object inserts attribute and its name into SAX attributes object.
    * 
    * @param    attributeName
    *           The attribute name to insert.
    * @param    attributeValue
    *           The attribute value to insert.
    * @param    namespaceUri
    *           The URI of the attribute to insert or '?' for unknown value.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   public logical insertAttribute(String attributeName, Text attributeValue,
                                  Text namespaceUri);

   /**
    * Adding the single attribute to the start tag in the XML document if applied for SAX writer
    * object. For SAX attributes object inserts attribute and its name into SAX attributes object.
    * 
    * @param    attributeName
    *           The attribute name to insert.
    * @param    attributeValue
    *           The attribute value to insert.
    * @param    namespaceUri
    *           The URI of the attribute to insert or '?' for unknown value.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   public logical insertAttribute(Text attributeName, String attributeValue,
                                  Text namespaceUri);

   /**
    * Adding the single attribute to the start tag in the XML document if applied for SAX writer
    * object. For SAX attributes object inserts attribute and its name into SAX attributes object.
    * 
    * @param    attributeName
    *           The attribute name to insert.
    * @param    attributeValue
    *           The attribute value to insert.
    * @param    namespaceUri
    *           The URI of the attribute to insert or '?' for unknown value.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   public logical insertAttribute(Text attributeName, Text attributeValue,
                                  String namespaceUri);

   /**
    * Adding the single attribute to the start tag in the XML document if applied for SAX writer
    * object. For SAX attributes object inserts attribute and its name into SAX attributes object.
    * 
    * @param    attributeName
    *           The attribute name to insert.
    * @param    attributeValue
    *           The attribute value to insert.
    * @param    namespaceUri
    *           The URI of the attribute to insert or '?' for unknown value.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   public logical insertAttribute(String attributeName, String attributeValue,
                                  Text namespaceUri);

   /**
    * Adding the single attribute to the start tag in the XML document if applied for SAX writer
    * object. For SAX attributes object inserts attribute and its name into SAX attributes object.
    * 
    * @param    attributeName
    *           The attribute name to insert.
    * @param    attributeValue
    *           The attribute value to insert.
    * @param    namespaceUri
    *           The URI of the attribute to insert or '?' for unknown value.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   public logical insertAttribute(String attributeName, Text attributeValue,
                                  String namespaceUri);

   /**
    * Adding the single attribute to the start tag in the XML document if applied for SAX writer
    * object. For SAX attributes object inserts attribute and its name into SAX attributes object.
    * 
    * @param    attributeName
    *           The attribute name to insert.
    * @param    attributeValue
    *           The attribute value to insert.
    * @param    namespaceUri
    *           The URI of the attribute to insert or '?' for unknown value.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   public logical insertAttribute(Text attributeName, String attributeValue,
                                  String namespaceUri);

   /**
    * Adding the single attribute to the start tag in the XML document if applied for SAX writer
    * object. For SAX attributes object inserts attribute and its name into SAX attributes object.
    * 
    * @param    attributeName
    *           The attribute name to insert.
    * @param    attributeValue
    *           The attribute value to insert.
    * @param    namespaceUri
    *           The URI of the attribute to insert or '?' for unknown value.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   public logical insertAttribute(String attributeName, String attributeValue,
                                  String namespaceUri);

   /**
    * Adding the single attribute to the start tag in the XML document if applied for SAX writer
    * object. For SAX attributes object inserts attribute and its name into SAX attributes object.
    * 
    * @param    attributeName
    *           The attribute name to insert.
    * @param    attributeValue
    *           The attribute value to insert.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   public logical insertAttribute(Text attributeName, Text attributeValue);

   /**
    * Adding the single attribute to the start tag in the XML document if applied for SAX writer
    * object. For SAX attributes object inserts attribute and its name into SAX attributes object.
    * 
    * @param    attributeName
    *           The attribute name to insert.
    * @param    attributeValue
    *           The attribute value to insert.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   public logical insertAttribute(String attributeName, Text attributeValue);

   /**
    * Adding the single attribute to the start tag in the XML document if applied for SAX writer
    * object. For SAX attributes object inserts attribute and its name into SAX attributes object.
    * 
    * @param    attributeName
    *           The attribute name to insert.
    * @param    attributeValue
    *           The attribute value to insert.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   public logical insertAttribute(Text attributeName, String attributeValue);

   /**
    * Adding the single attribute to the start tag in the XML document if applied for SAX writer
    * object. For SAX attributes object inserts attribute and its name into SAX attributes object.
    * 
    * @param    attributeName
    *           The attribute name to insert.
    * @param    attributeValue
    *           The attribute value to insert.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   public logical insertAttribute(String attributeName, String attributeValue);
}
