/*
** Module   : SaxEntityImpl
** Abstract : SAX attributes, reader, writer common fatures iplementation.
**
** Copyright (c) 2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ---------------------------------Description----------------------------------
** 001 EVL 20130208 Created initial version. Implementation is limited to the stubs to get the
**                  converted java code compiled.
*/

package com.goldencode.p2j.xml;

import com.goldencode.p2j.util.*;

/**
 * Implementation the common features for SAX Reader, SAX Writer and SAX Attributes Progress
 * support objects.
 */
public class SaxEntityImpl
extends XCommonImpl
implements SaxEntity
{
   // Attributes
   // Methods
   /**
    * Adding the single attribute to the start tag in the XML document if applied for SAX writer
    * object. For SAX attributes object inserts attribute and its name into SAX attributes object.
    * 
    * @param    attributeName
    *           The attribute name to insert.
    * @param    attributeValue
    *           The attribute value to insert.
    * @param    namespaceUri
    *           The URI of the attribute to insert or '?' for unknown value.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   public logical insertAttribute(String attributeName, Text attributeValue, Text namespaceUri)
   {
      return insertAttribute(new character(attributeName), attributeValue, namespaceUri);
   }

   /**
    * Adding the single attribute to the start tag in the XML document if applied for SAX writer
    * object. For SAX attributes object inserts attribute and its name into SAX attributes object.
    * 
    * @param    attributeName
    *           The attribute name to insert.
    * @param    attributeValue
    *           The attribute value to insert.
    * @param    namespaceUri
    *           The URI of the attribute to insert or '?' for unknown value.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   public logical insertAttribute(Text attributeName, String attributeValue, Text namespaceUri)
   {
      return insertAttribute(attributeName, new character(attributeValue), namespaceUri);
   }

   /**
    * Adding the single attribute to the start tag in the XML document if applied for SAX writer
    * object. For SAX attributes object inserts attribute and its name into SAX attributes object.
    * 
    * @param    attributeName
    *           The attribute name to insert.
    * @param    attributeValue
    *           The attribute value to insert.
    * @param    namespaceUri
    *           The URI of the attribute to insert or '?' for unknown value.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   public logical insertAttribute(Text attributeName, Text attributeValue, String namespaceUri)
   {
      return insertAttribute(attributeName, attributeValue, new character(namespaceUri));
   }

   /**
    * Adding the single attribute to the start tag in the XML document if applied for SAX writer
    * object. For SAX attributes object inserts attribute and its name into SAX attributes object.
    * 
    * @param    attributeName
    *           The attribute name to insert.
    * @param    attributeValue
    *           The attribute value to insert.
    * @param    namespaceUri
    *           The URI of the attribute to insert or '?' for unknown value.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   public logical insertAttribute(String attributeName, String attributeValue, Text namespaceUri)
   {
      return insertAttribute(new character(attributeName), new character(attributeValue),
                             namespaceUri);
   }

   /**
    * Adding the single attribute to the start tag in the XML document if applied for SAX writer
    * object. For SAX attributes object inserts attribute and its name into SAX attributes object.
    * 
    * @param    attributeName
    *           The attribute name to insert.
    * @param    attributeValue
    *           The attribute value to insert.
    * @param    namespaceUri
    *           The URI of the attribute to insert or '?' for unknown value.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   public logical insertAttribute(String attributeName, Text attributeValue, String namespaceUri)
   {
      return insertAttribute(new character(attributeName), attributeValue,
                             new character(namespaceUri));
   }

   /**
    * Adding the single attribute to the start tag in the XML document if applied for SAX writer
    * object. For SAX attributes object inserts attribute and its name into SAX attributes object.
    * 
    * @param    attributeName
    *           The attribute name to insert.
    * @param    attributeValue
    *           The attribute value to insert.
    * @param    namespaceUri
    *           The URI of the attribute to insert or '?' for unknown value.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   public logical insertAttribute(Text attributeName, String attributeValue, String namespaceUri)
   {
      return insertAttribute(attributeName, new character(attributeValue),
                             new character(namespaceUri));
   }

   /**
    * Adding the single attribute to the start tag in the XML document if applied for SAX writer
    * object. For SAX attributes object inserts attribute and its name into SAX attributes object.
    * 
    * @param    attributeName
    *           The attribute name to insert.
    * @param    attributeValue
    *           The attribute value to insert.
    * @param    namespaceUri
    *           The URI of the attribute to insert or '?' for unknown value.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   public logical insertAttribute(String attributeName, String attributeValue,
                                  String namespaceUri)
   {
      return insertAttribute(new character(attributeName), new character(attributeValue),
                             new character(namespaceUri));
   }
   
   /**
    * Adding the single attribute to the start tag in the XML document if applied for SAX writer
    * object. For SAX attributes object inserts attribute and its name into SAX attributes object.
    * 
    * @param    attributeName
    *           The attribute name to insert.
    * @param    attributeValue
    *           The attribute value to insert.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   public logical insertAttribute(String attributeName, Text attributeValue)
   {
      return insertAttribute(new character(attributeName), attributeValue, new character());
   }

   /**
    * Adding the single attribute to the start tag in the XML document if applied for SAX writer
    * object. For SAX attributes object inserts attribute and its name into SAX attributes object.
    * 
    * @param    attributeName
    *           The attribute name to insert.
    * @param    attributeValue
    *           The attribute value to insert.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   public logical insertAttribute(Text attributeName, String attributeValue)
   {
      return insertAttribute(attributeName, new character(attributeValue), new character());
   }

   /**
    * Adding the single attribute to the start tag in the XML document if applied for SAX writer
    * object. For SAX attributes object inserts attribute and its name into SAX attributes object.
    * 
    * @param    attributeName
    *           The attribute name to insert.
    * @param    attributeValue
    *           The attribute value to insert.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   public logical insertAttribute(String attributeName, String attributeValue)
   {
      return insertAttribute(new character(attributeName), new character(attributeValue),
                             new character());
   }

   /**
    * Adding the single attribute to the start tag in the XML document if applied for SAX writer
    * object. For SAX attributes object inserts attribute and its name into SAX attributes object.
    * 
    * @param    attributeName
    *           The attribute name to insert.
    * @param    attributeValue
    *           The attribute value to insert.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   public logical insertAttribute(Text attributeName, Text attributeValue)
   {
      return insertAttribute(attributeName, attributeValue, new character());
   }
   
   /**
    * Adding the single attribute to the start tag in the XML document if applied for SAX writer
    * object. For SAX attributes object inserts attribute and its name into SAX attributes object.
    * 
    * @param    attributeName
    *           The attribute name to insert.
    * @param    attributeValue
    *           The attribute value to insert.
    * @param    namespaceUri
    *           The URI of the attribute to insert or '?' for unknown value.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   public logical insertAttribute(Text attributeName, Text attributeValue, Text namespaceUri)
   {
      // TODO:
      return new logical(true);
   }
}
