/*
** Module   : XCommon
** Abstract : XML related generic common interface.
**
** Copyright (c) 2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ---------------------------------Description----------------------------------
** 001 EVL 20130214 Created initial version.
*/

package com.goldencode.p2j.xml;

import com.goldencode.p2j.util.*;

/**
 * Interface decribing the common features for XML related objects.
 */
public interface XCommon
extends WrappedResource
{
   // Attributes
   /**
    * Gets the value of the XML schema file for elements with no namespaces.  
    *
    * @return   The value of the nonamespace-schema-location attribute.
    */
   public character getNonamespaceSchemaLocation();
   
   /**
    * Setting the new value for the nonamespace-schema-location attribute.
    * 
    * @param    nonamespaceSchemaLocation
    *           New value of the nonamespace-schema-location attribute to set.
    */
   public void setNonamespaceSchemaLocation(character nonamespaceSchemaLocation);
   
   /**
    * Setting the new value for the nonamespace-schema-location attribute.
    * 
    * @param    nonamespaceSchemaLocation
    *           New value of the nonamespace-schema-location attribute to set.
    */
   public void setNonamespaceSchemaLocation(String nonamespaceSchemaLocation);
   
   // Methods
   /**
    * Adding new match pair for namespace schema and physical file location.
    * 
    * @param    targetNamespace
    *           Target namespace of the schema or am empty string or Unknown value.
    * @param    location
    *           Location of the XML schema file.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   public logical addSchemaLocation(character targetNamespace, character location);

   /**
    * Adding new match pair for namespace schema and physical file location.
    * 
    * @param    targetNamespace
    *           Target namespace of the schema or am empty string or Unknown value.
    * @param    location
    *           Location of the XML schema file.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   public logical addSchemaLocation(String targetNamespace, character location);

   /**
    * Adding new match pair for namespace schema and physical file location.
    * 
    * @param    targetNamespace
    *           Target namespace of the schema or am empty string or Unknown value.
    * @param    location
    *           Location of the XML schema file.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   public logical addSchemaLocation(character targetNamespace, String location);

   /**
    * Adding new match pair for namespace schema and physical file location.
    * 
    * @param    targetNamespace
    *           Target namespace of the schema or am empty string or Unknown value.
    * @param    location
    *           Location of the XML schema file.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   public logical addSchemaLocation(String targetNamespace, String location);
   
   /**
    * Removes the specified attribute.
    * 
    * @param    attrName
    *           The name of the attribute to remove.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   public logical removeAttribute(character attrName);
   
   /**
    * Removes the specified attribute.
    * 
    * @param    attrName
    *           The name of the attribute to remove.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   public logical removeAttribute(String attrName);
   
   /**
    * Removes the specified attribute.
    * 
    * @param    index
    *           The 1-based index of the attribute to remove.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   public logical removeAttribute(integer index);
   
   /**
    * Removes the specified attribute.
    * 
    * @param    index
    *           The 1-based index of the attribute to remove.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   public logical removeAttribute(int index);

   /**
    * Removes the specified attribute.
    * 
    * @param    attrName
    *           The name of the attribute to remove.
    * @param    namespaceUri
    *           The URI of the attribute to remove.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   public logical removeAttribute(character attrName, character namespaceUri);
   
   /**
    * Removes the specified attribute.
    * 
    * @param    attrName
    *           The name of the attribute to remove.
    * @param    namespaceUri
    *           The URI of the attribute to remove.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   public logical removeAttribute(String attrName, character namespaceUri);
   
   /**
    * Removes the specified attribute.
    * 
    * @param    index
    *           The 1-based index of the attribute to remove.
    * @param    namespaceUri
    *           The URI of the attribute to remove.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   public logical removeAttribute(integer index, character namespaceUri);
   
   /**
    * Removes the specified attribute.
    * 
    * @param    index
    *           The 1-based index of the attribute to remove.
    * @param    namespaceUri
    *           The URI of the attribute to remove.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   public logical removeAttribute(int index, character namespaceUri);

   /**
    * Removes the specified attribute.
    * 
    * @param    attrName
    *           The name of the attribute to remove.
    * @param    namespaceUri
    *           The URI of the attribute to remove.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   public logical removeAttribute(character attrName, String namespaceUri);
   
   /**
    * Removes the specified attribute.
    * 
    * @param    attrName
    *           The name of the attribute to remove.
    * @param    namespaceUri
    *           The URI of the attribute to remove.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   public logical removeAttribute(String attrName, String namespaceUri);
   
   /**
    * Removes the specified attribute.
    * 
    * @param    index
    *           The 1-based index of the attribute to remove.
    * @param    namespaceUri
    *           The URI of the attribute to remove.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   public logical removeAttribute(integer index, String namespaceUri);
   
   /**
    * Removes the specified attribute.
    * 
    * @param    index
    *           The 1-based index of the attribute to remove.
    * @param    namespaceUri
    *           The URI of the attribute to remove.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   public logical removeAttribute(int index, String namespaceUri);
}
